@@ -14,12 +14,13 @@ from . import errors
 
 
 class FileUploader(object):
-    def __init__(self, pack):
+    def __init__(self, pack, display_progress: bool = False):
         self._logger = get_oort_logger('uploader', debug=True)
 
         self._pack = pack
         self._upload = self._pack.upload
         self._final_file_path = pathlib.Path(self._pack.final_file_path)
+        self._display_progress = display_progress
 
         is_test_context = bool(os.environ.get('OORT_TESTS') == '1')
         self._api = ArcsecondAPI.datafiles(dataset=str(self._upload.dataset.uuid),  # will be used as request prefix
@@ -36,10 +37,13 @@ class FileUploader(object):
         # Callback allowing for the server monitor to display the percentage of progress of the upload.
         def update_upload_progress(event, progress_percent):
             if progress_percent > self._upload.progress + 0.1 or progress_percent > 99:
+                duration = (datetime.now() - self._upload.started).total_seconds()
                 self._upload.smart_update(status=Status.UPLOADING.value,
                                           substatus=Substatus.UPLOADING.value,
                                           progress=progress_percent,
-                                          duration=(datetime.now() - self._upload.started).total_seconds())
+                                          duration=duration)
+                if self._display_progress is True:
+                    print(f"{progress_percent:.2f}% ({duration:.2f} sec)", end="\r")
 
         ffps = str(self._final_file_path)
 
@@ -120,7 +124,25 @@ class FileUploader(object):
 
         return _should_perform
 
-    def _perform(self):
+    def _process_error(self, error):
+        status, substatus, error = Status.ERROR.value, Substatus.ERROR.value, str(error)
+
+        try:
+            error_body = json.loads(error)
+        except Exception as err:
+            self._logger.error(str(err))
+        else:
+            if 'detail' in error_body.keys():
+                detail = error_body['detail']
+                error_content = detail[0] if isinstance(detail, list) and len(detail) > 0 else detail
+                if 'already exists in dataset' in error_content:
+                    status, substatus, error = Status.OK.value, Substatus.ALREADY_SYNCED.value, ''
+
+        self._upload.smart_update(status=status, substatus=substatus, error=error)
+
+    def upload_file(self):
+        self._logger.info(f'{self.log_prefix} Opening upload sequence.')
+
         if not self._check():
             return
 
@@ -142,25 +164,6 @@ class FileUploader(object):
             self._logger.info(msg)
             self._upload.smart_update(status=Status.OK.value, substatus=Substatus.DONE.value, error='')
 
-    def _process_error(self, error):
-        status, substatus, error = Status.ERROR.value, Substatus.ERROR.value, str(error)
-
-        try:
-            error_body = json.loads(error)
-        except Exception as err:
-            self._logger.error(str(err))
-        else:
-            if 'detail' in error_body.keys():
-                detail = error_body['detail']
-                error_content = detail[0] if isinstance(detail, list) and len(detail) > 0 else detail
-                if 'already exists in dataset' in error_content:
-                    status, substatus, error = Status.OK.value, Substatus.ALREADY_SYNCED.value, ''
-
-        self._upload.smart_update(status=status, substatus=substatus, error=error)
-
-    def upload_file(self):
-        self._logger.info(f'{self.log_prefix} Opening upload sequence.')
-        self._perform()
         self._logger.info(f'{self.log_prefix} Closing upload sequence.')
 
     @property
